@@ -25,6 +25,7 @@ from .__version__ import __version__
 from .apps import App, get_app
 from .auditing import audit
 from .browse import browse
+from .collect import collection_of
 from .component import Component, DynamicComponent
 from .context import context as system
 from .forms import form, Form
@@ -35,9 +36,9 @@ from .page import page, Page
 from .packages import requires
 from .store import store_of
 from .records import table_of
-from .sites import get_site
+from .sites import get_site, get_db
 from .tools import home, redirect_to, load, partial
-from .users import authorize, get_user
+from .users import authorize, can, get_user
 from .utils import Record
 
 __license__ = "MIT"
