@@ -594,6 +594,11 @@ def capture_stdout(request, handler, *rest):
     return result
 
 
+def cause_error(request, handler, *rest):
+    """Cause an error for testing"""
+    raise Exception('Something unexpected happened!')
+
+
 def trap_errors(request, handler, *rest):
     """Trap exceptions and raise a server error
 
@@ -612,14 +617,17 @@ def trap_errors(request, handler, *rest):
     >>> status, headers, content = response.as_wsgi()
     >>> status
     '500 Internal Server Error'
-    >>> 'Exception: error!' in str(content)
+    >>> 'Server Error' in str(content)
     True
     """
     try:
         return handler(request, *rest)
     except Exception:
         status = '500 Internal Server Error'
-        return TextResponse(traceback.format_exc(), status)
+        return HTMLResponse(
+            zoom.templates.internal_server_error_500,
+            status
+        )
 
 
 def display_errors(request, handler, *rest):
@@ -634,14 +642,21 @@ def display_errors(request, handler, *rest):
             zoom.templates.template_missing
         )
 
-    except Exception:
+    except Exception as e:
         msg = traceback.format_exc()
         logger = logging.getLogger(__name__)
         logger.error(msg)
 
+        as_api = request.env.get('HTTP_ACCEPT', '') == 'application/json'
+        error_status = '500 Internal Server Error'
+
         if not (hasattr(zoom.system, 'user') and zoom.system.user.is_admin):
-            content = zoom.tools.load_template('friendly_error', zoom.templates.friendly_error)
-            return page(content).render(request)
+            if as_api:
+                return JSONResponse(
+                    dict(status=error_status), status=error_status)
+            content = zoom.tools.load_template(
+                'friendly_error', zoom.templates.friendly_error)
+            return page(content, status=500).render(request)
 
         content = """
         <h2>Exception</h2>
@@ -654,9 +669,19 @@ def display_errors(request, handler, *rest):
             str(request),
         )
 
+        if as_api:
+            return JSONResponse(
+                dict(
+                    message=str(e),
+                    status=error_status,
+                ),
+                status=error_status
+            )
+
         return page(
             content,
-            title='Application Error'
+            title='Application Error',
+            status='500 Internal Server Error'
         ).render(request)
 
 
