@@ -19,6 +19,8 @@ keep_these = string.ascii_letters + string.digits + '.-_ '
 delete_these = chars.translate(str.maketrans(chars, chars, keep_these))
 allowed = str.maketrans(keep_these, keep_these, delete_these)
 
+logger = logging.getLogger(__name__)
+
 
 def key_for(username):
     """
@@ -559,6 +561,7 @@ class Users(RecordStore):
         """Things to do just before inserting a new User record"""
         user.update(status='A')
         user.created = user.updated = zoom.tools.now()
+        user.created_by = user.updated_by = get_user().user_id
 
     def before_update(self, user):
         """Things to do just before updating a User record"""
@@ -612,6 +615,11 @@ def authorize(*roles):
     return wrapper
 
 
+def can(action, thing):
+    """Return True if current user can action thing"""
+    return get_user().can(action, thing)
+
+
 def set_current_user(request):
     """Set current user
 
@@ -653,9 +661,29 @@ def set_current_user(request):
         raise Exception('Unable to initialize user')
 
 
-def get_user():
-    """Return the currrent user object"""
-    return zoom.system.request.user
+def get_users():
+    """Get the users store"""
+    return zoom.get_site().users
+
+
+def get_user(key=None):
+    """Return the currrent user or a specified user"""
+    if key is None:
+        return zoom.system.request.user
+    users = get_users()
+    user = users.get(key)
+    if user:
+        return user
+    user = users.locate(key)
+    if user:
+        logger.warning('get_user with parameter other than user_id is deprecated.  Use locate_user instead.')
+        return user
+
+
+def locate_user(key):
+    """Locate a user"""
+    users = get_users()
+    return users.get(key) or users.locate(key)
 
 
 def handler(request, next_handler, *rest):
