@@ -14,9 +14,9 @@ import os
 import string
 import uuid
 
-import zoom
 import zoom.jsonz as json
 
+
 POSITIVE = [True, 1, 'True', 'yes', 'y', 'on', '1']
 NEGATIVE = [False, 0, 'False', 'no', 'n', 'off', '0']
 
@@ -25,10 +25,12 @@ keep_these = string.ascii_letters + string.digits + '-_ '
 delete_these = chars.translate(str.maketrans(chars, chars, keep_these))
 allowed = str.maketrans(keep_these, keep_these, delete_these)
 
+
 def create_csrf_token():
     """Create and return a canonical CSRF token; a un-segmented UUID4."""
     return uuid.uuid4().hex
 
+
 def pretty(obj):
     """return an object in a pretty form
 
@@ -476,6 +478,7 @@ class ItemList(list):
 
 
 def parents(path):
+    """Return list of parent directories"""
     if not os.path.isdir(path):
         return parents(os.path.split(os.path.abspath(path))[0])
     parent = os.path.abspath(os.path.join(path, os.pardir))
@@ -506,6 +509,7 @@ class Config(object):
 
     A Config with a handy get method.
 
+    >>> import zoom
     >>> config = Config(zoom.tools.zoompath('zoom', '_assets', 'web','sites','default','site.ini'))
     >>> config.get('site', 'name')
     'ZOOM'
@@ -628,9 +632,9 @@ class OrderedSet(collections.MutableSet):
             OrderedSet([2, 3])
         """
         if key in self.map:
-            key, prev, next = self.map.pop(key)
-            prev[2] = next
-            next[1] = prev
+            key, prev, _next = self.map.pop(key)
+            prev[2] = _next
+            _next[1] = prev
 
     def __iter__(self):
         end = self.end
@@ -807,7 +811,7 @@ class Record(Storage):
     def save(self):
         """save record"""
         logger = logging.getLogger(__name__)
-        id = self['__store'].put(self)
+        record_id = self['__store'].put(self)
         key = self['__store'].id_name
         logger.debug(
             'saved record %s(%s=%r) to %r',
@@ -816,7 +820,7 @@ class Record(Storage):
             self[key],
             self['__store']
         )
-        return id
+        return record_id
 
     def attributes(self):
         return get_attributes(self)
@@ -839,14 +843,22 @@ class Record(Storage):
         try:
             value = dict.__getitem__(self, name)
             if hasattr(value, '__get__'):
-                return value.__get__(self)
+                getter = getattr(value, '__get__')
+                if getter is not None:
+                    return getter(self)
+                else:
+                    return value
             else:
                 return value
         except KeyError as k:
             try:
                 value = self.__class__.__dict__[name]
                 if hasattr(value, '__get__'):
-                    return value.__get__(self)
+                    getter = getattr(value, '__get__')
+                    if getter:
+                        return getter(self)
+                    else:
+                        return value
                 else:
                     return value
             except KeyError as k:
@@ -1081,6 +1093,7 @@ def search(items, text):
         if matches(item, search_terms):
             yield item
 
+
 def generate_key():
     """make a new key
 
@@ -1090,6 +1103,7 @@ def generate_key():
     new_uuid = uuid.uuid4().bytes
     return hmac.new(new_uuid, digestmod=hashlib.sha1).hexdigest()
 
+
 def existing(path, subdir=None):
     """Returns existing directories only"""
     realpath = os.path.realpath
@@ -1103,6 +1117,7 @@ def existing(path, subdir=None):
     if pathname and exists(pathname):
         return pathname
 
+
 def dedup(seq):
     """Remove duplicates while retaining order"""
     seen = set()
